@@ -85,6 +85,20 @@ class FakeVolume(object):
         self.display_name = display_name
 
 
+class FakeMachine(object):
+    def __init__(self, id, name=None, driver=None, driver_info=None,
+                 chassis_uuid=None, instance_info=None, instance_uuid=None,
+                 properties=None):
+        self.id = id
+        self.name = name
+        self.driver = driver
+        self.driver_info = driver_info
+        self.chassis_uuid = chassis_uuid
+        self.instance_info = instance_info
+        self.instance_uuid = instance_uuid
+        self.properties = properties
+
+
 class FakeMachinePort(object):
     def __init__(self, id, address, node_id):
         self.id = id
