@@ -114,9 +114,8 @@ class TestShade(base.TestCase):
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
     def test_delete_router_not_found(self, mock_client, mock_search):
         mock_search.return_value = []
-        self.assertRaises(exc.OpenStackCloudException,
-                          self.cloud.delete_router,
-                          'goofy')
+        r = self.cloud.delete_router('goofy')
+        self.assertFalse(r)
         self.assertFalse(mock_client.delete_router.called)
 
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
@@ -186,9 +185,8 @@ class TestShade(base.TestCase):
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
     def test_delete_subnet_not_found(self, mock_client, mock_search):
         mock_search.return_value = []
-        self.assertRaises(exc.OpenStackCloudException,
-                          self.cloud.delete_subnet,
-                          'goofy')
+        r = self.cloud.delete_subnet('goofy')
+        self.assertFalse(r)
         self.assertFalse(mock_client.delete_subnet.called)
 
     @mock.patch.object(shade.OpenStackCloud, 'neutron_client')
@@ -313,6 +311,22 @@ class TestShadeOperator(base.TestCase):
             '00000000-0000-0000-0000-000000000000')
         self.assertEqual(machine, expected_value)
 
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_list_machines(self, mock_client):
+        m1 = fakes.FakeMachine(1, 'fake_machine1')
+        mock_client.node.list.return_value = [m1]
+        machines = self.cloud.list_machines()
+        self.assertTrue(mock_client.node.list.called)
+        self.assertEqual(meta.obj_to_dict(m1), machines[0])
+
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_validate_node(self, mock_client):
+        node_uuid = '123'
+        self.cloud.validate_node(node_uuid)
+        mock_client.node.validate.assert_called_once_with(
+            node_uuid=node_uuid
+        )
+
     @mock.patch.object(shade.OperatorCloud, 'ironic_client')
     def test_list_nics(self, mock_client):
         port1 = fakes.FakeMachinePort(1, "aa:bb:cc:dd", "node1")
